from browser import document, bind
from src.lexer import Lexer
from src._parser import Parser
from src.interpreter import Interpreter, Context, global_symbol_table
import sys

@bind("#run", "click")
def run(event):
	code = document['code'].value # code are
	rs = document['result'] # result area
	rs.value = ""
	# Generate tokens
	lexer = Lexer("<stdin>", code)
	tokens, error = lexer.create_tokens()
	if error:
		print(error.as_string())
		rs.value = error.as_string() #setting erro msg for result area
		return None

	# Generate AST
	parser = Parser(tokens)
	ast = parser.parse()
	if ast.error:
		print (ast.error.as_string())
		rs.value += ast.error.as_string() #setting erro msg for result area
		return None

	# Run program
	interpreter = Interpreter()
	context = Context('<program>')
	context.symbol_table = global_symbol_table
	result = interpreter.visit(ast.node, context)
	if result.error:
		print(result.error.as_string())
		rs.value += result.error.as_string() #setting erro msg for result area
	return result.value, result.error